==> hyades.source_1.1.0_20030930_2244.zip: org/eclipse/hyades/log/ui/internal/wizards/LogHostUI.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
/*
 * Created on Aug 5, 2003
 *
 */
package org.eclipse.hyades.log.ui.internal.wizards;

import org.eclipse.hyades.trace.ui.HyadesConstants;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.hyades.trace.ui.internal.core.TraceHostUI;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.TableItem;

/**
 * @author apnan
 * 
 */
public class LogHostUI extends TraceHostUI {
	
	/**
	 * @param wp
	 */
	public LogHostUI(WizardPage wp) {
		super(wp);		
	}

	/**
	 * 
	 */
	public LogHostUI() {
		super();
	}
	public void widgetSelected(SelectionEvent e){
		super.widgetSelected(e);
		LogFileElement element = ((ImportLogWizardPage) getWizardPage()).getSelectedElement();
		element.setHost(getHost());
		((ImportLogWizardPage)getWizardPage()).getDialog().setOKButtonEnabled(getHost()!=null);
		((ImportLogWizardPage)getWizardPage()).initLocation();
	}
	
	public void initialize(LogFileElement element){	
			
		String host = element.getHost();
		if(getHosts().length==0){
			element.setHost(null);
		}else{
			if(host==null){
				String newHost = getHost();
				element.setHost(newHost);
			}else{
				selectHost(host);
			}
		
		}
	}

	public void selectHost(String hostname)
	{
		if(!isLocalHost(hostname)){
			super.selectHost(hostname);
		}
		else{
			super.selectHost("localhost");
		}
	}
	
	public boolean finish() {
		
		IPreferenceStore store = UIPlugin.getDefault().getPreferenceStore();

		String hosts = "";

		TableItem[] items = getHosts();
		
		if(items.length==0){
			return false;
		}
		
		for (int idx = 0; idx < items.length; idx++) {
			hosts += "," + items[idx].getText().trim();
		}

		if (hosts.startsWith(",") && hosts.length() > 1)
			hosts = hosts.substring(1);

		store.setValue(HyadesConstants.HOST_KEY, hosts);
		
		return true;

	}
	

}

==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/log/ui/internal/wizards/LogHostUI.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
/*
 * Created on Aug 5, 2003
 *
 */
package org.eclipse.hyades.log.ui.internal.wizards;

import org.eclipse.hyades.trace.ui.HyadesConstants;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.hyades.trace.ui.internal.core.TraceHostUI;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.TableItem;

/**
 * @author apnan
 * 
 */
public class LogHostUI extends TraceHostUI {
	
	/**
	 * @param wp
	 */
	public LogHostUI(WizardPage wp) {
		super(wp);		
	}

	/**
	 * 
	 */
	public LogHostUI() {
		super();
	}
	public void widgetSelected(SelectionEvent e){
		super.widgetSelected(e);
		//LogFileElement element = ((ImportLogWizardPage) getWizardPage()).getSelectedElement();
		//element.setHost(getHost());
		((ImportLogWizardPage)getWizardPage()).getDialog().setOKButtonEnabled(isTabItemComplete());
		((ImportLogWizardPage)getWizardPage()).initLocation();
	}
	
	public void initialize(LogFileElement element){	
			
		String host = element.getHost();
		if(host!=null){
			selectHost(host);		
		}
	}

	public boolean isTabItemComplete(){
		return getHost()!=null;
	}
	
	public void selectHost(String hostname)
	{
		if(!isLocalHost(hostname)){
			super.selectHost(hostname);
		}
		else{
			super.selectHost("localhost");
		}
	}
	
	public boolean finish() {
		
		LogFileElement element = ((ImportLogWizardPage) getWizardPage()).getSelectedElement();
		element.setHost(getHost());
		
		IPreferenceStore store = UIPlugin.getDefault().getPreferenceStore();

		String hosts = "";

		TableItem[] items = getHosts();
		
		if(items.length==0){
			return false;
		}
		
		for (int idx = 0; idx < items.length; idx++) {
			hosts += "," + items[idx].getText().trim();
		}

		if (hosts.startsWith(",") && hosts.length() > 1)
			hosts = hosts.substring(1);

		store.setValue(HyadesConstants.HOST_KEY, hosts);
		
		return true;

	}
	

}
